req_contract_details – ShinyBroker

# req_contract_details

`req_contract_details(reqId, contract)`

Create a contract details request string

## Parameters

Name | Type | Description | Default
--- | --- | --- | ---
`reqId` | int | Numeric identifier of the request | required
`contract` | Contract | A Contract object | required

## Examples

    import shinybroker as sb
    req_contract_details_msg = sb.req_contract_details(
        reqId=1,
        contract=Contract({
            'symbol': "AAPL",
            'secType': "STK",
            'exchange': "SMART",
            'currency': "USD"
        })
    )
    print(req_contract_details_msg)